import * as cdk from "aws-cdk-lib";
import * as codepipeline from "aws-cdk-lib/aws-codepipeline";
import * as codestarnotifications from "aws-cdk-lib/aws-codestarnotifications";
import * as iam from "aws-cdk-lib/aws-iam";
import * as kms from "aws-cdk-lib/aws-kms";
import * as pipelines from "aws-cdk-lib/pipelines";
import { Construct } from "constructs";
import { BaseStack, BaseStackProps } from "../base";
import { Configurator } from "../config";
export interface SourceActionProps {
    readonly sourceAction?: pipelines.CodePipelineSource;
    readonly repositoryName: string;
    readonly branch?: string;
}
export interface SynthActionProps {
    readonly cdkVersion?: string;
    readonly codeartifactRepository?: string;
    readonly codeartifactDomain?: string;
    readonly codeartifactDomainOwner?: string;
    readonly rolePolicyStatements?: iam.PolicyStatement[];
    readonly synthAction?: pipelines.CodeBuildStep;
    readonly additionalInstallCommands?: string[];
}
export interface AddApplicationStageProps {
    readonly stageId: string;
    readonly stage: cdk.Stage;
    readonly manualApprovals?: boolean;
}
export interface AddApplicationWaveProps {
    readonly stageId: string;
    readonly stages: cdk.Stage[];
    readonly manualApprovals?: boolean;
}
export interface AddSecurityLintStageProps {
    readonly stageName?: string;
    readonly cloudAssemblyFileSet?: pipelines.IFileSetProducer;
}
export interface AddTestStageProps {
    readonly stageName?: string;
    readonly cloudAssemblyFileSet?: pipelines.IFileSetProducer;
    readonly commands?: string[];
}
export interface AddNotificationsProps {
    readonly notificationRule?: codestarnotifications.NotificationRule;
}
export interface AddCustomStageProps {
    readonly stageName: string;
    readonly steps: pipelines.Step[];
}
export interface CICDPipelineStackProps extends BaseStackProps {
    readonly pipelineName?: string;
    readonly cdkLanguage?: string;
}
export interface AdditionalPipelineProps {
    readonly assetPublishingCodeBuildDefaults?: pipelines.CodeBuildOptions;
    readonly cliVersion?: string;
    readonly codeBuildDefaults?: pipelines.CodeBuildOptions;
    readonly codePipeline?: codepipeline.Pipeline;
    readonly dockerCredentials?: pipelines.DockerCredential[];
    readonly dockerEnabledForSelfMutation?: boolean;
    readonly dockerEnabledForSynth?: boolean;
    readonly publishAssetsInParallel?: boolean;
    readonly reuseCrossRegionSupportStacks?: boolean;
    readonly selfMutation?: boolean;
    readonly selfMutationCodeBuildDefaults?: pipelines.CodeBuildOptions;
    readonly synthCodeBuildDefaults?: pipelines.CodeBuildOptions;
}
export declare class CICDPipelineStack extends BaseStack {
    readonly environmentId?: string;
    readonly pipelineName?: string;
    readonly pipelineId?: string;
    readonly config: Configurator;
    readonly cdkLanguage: string;
    notificationRule?: codestarnotifications.NotificationRule;
    pipeline?: pipelines.CodePipeline;
    pipelineKey?: kms.CfnKey;
    sourceAction?: pipelines.CodePipelineSource;
    synthAction?: pipelines.CodeBuildStep;
    constructor(scope: Construct, id: string, props: CICDPipelineStackProps);
    addSourceAction(props: SourceActionProps): this;
    buildPipeline(props?: AdditionalPipelineProps): this;
    addSynthAction(props?: SynthActionProps): this;
    addStage(props: AddApplicationStageProps): this;
    addWave(props: AddApplicationWaveProps): this;
    addSecurityLintStage(props: AddSecurityLintStageProps): this;
    addTestStage(props: AddTestStageProps): this;
    addNotifications(props?: AddNotificationsProps): this;
    addChecks(): this;
    addCustomStage(props: AddCustomStageProps): this;
    synth(): this;
}
