import * as cloudwatch from "aws-cdk-lib/aws-cloudwatch";
import * as events from "aws-cdk-lib/aws-events";
import * as iam from "aws-cdk-lib/aws-iam";
import * as sfn from "aws-cdk-lib/aws-stepfunctions";
import { Construct } from "constructs";
export interface StageProps {
    readonly name?: string;
    readonly description?: string;
}
export declare abstract class Stage extends Construct {
    readonly name?: string;
    readonly description?: string;
    abstract readonly targets?: events.IRuleTarget[];
    abstract readonly eventPattern?: events.EventPattern;
    constructor(scope: Construct, id: string, props: StageProps);
}
export interface DataStageProps extends StageProps {
    readonly alarmsEnabled?: boolean;
}
export interface AlarmProps {
    readonly metric: cloudwatch.IMetric;
    readonly comparisonOperator?: cloudwatch.ComparisonOperator;
    readonly evaluationPeriods?: number;
    readonly threshold?: number;
}
export declare abstract class DataStage extends Stage {
    readonly cloudwatchAlarms: cloudwatch.Alarm[];
    readonly alarmsEnabled: boolean;
    constructor(scope: Construct, id: string, props: DataStageProps);
    addAlarm(id: string, props: AlarmProps): DataStage;
}
export interface StateMachineStageProps extends StageProps {
    readonly stateMachineInput?: {
        [key: string]: any;
    };
    readonly stateMachineName?: string;
    readonly additionalRolePolicyStatements?: iam.PolicyStatement[];
    readonly stateMachineFailedExecutionsAlarmThreshold?: number;
    readonly stateMachineFailedExecutionsAlarmEvaluationPeriods?: number;
    readonly alarmsEnabled?: boolean;
}
export interface CreateStateMachineResult {
    readonly eventPattern: events.EventPattern;
    readonly targets: events.IRuleTarget[];
    readonly stateMachine: sfn.StateMachine;
}
export declare abstract class StateMachineStage extends DataStage {
    abstract readonly stateMachine: sfn.StateMachine;
    constructor(scope: Construct, id: string, props: StateMachineStageProps);
    protected createStateMachine(definition: sfn.IChainable, props: StateMachineStageProps): CreateStateMachineResult;
}
export interface EventStageProps extends StageProps {
}
export declare abstract class EventStage extends Stage {
    readonly targets?: events.IRuleTarget[];
    constructor(scope: Construct, id: string, props: EventStageProps);
}
